@@ -2,8 +2,8 @@ from typing import List, Generator
 from pathlib import Path
 from collections import defaultdict
 
-from mecab_exception import MecabDataReaderException
-from mecab_parser import MecabParser
+from .mecab_exception import MecabDataReaderException
+from .mecab_parser import MecabParser
 
 
 class CategoryData:
